{*******************************************************}
{                                                       }
{         Vladimir Gaitanoff Delphi VCL Library         }
{         TvgHasp                                       }
{         Aladdin HASP API wrapper                      }
{                                                       }
{         Copyright (c) 1997, 1998                      }
{                                                       }
{*******************************************************}
{$D-,L- }

unit vgHasp;

interface
uses Windows, SysUtils, Classes;

type
  THaspMode            = (hmHasp, hmMemoHasp1, hmMemoHasp4, hmTimeHasp, hmTimeHasp4, hmNetHasp);
  THaspModes           = set of THaspMode;

  THaspPort            = (hpIBM25, hpIBM36, hpNEC36);
  THaspMemorySize      = (msZero, msMemoHasp1, msMemoHasp4);

  TNumPasswords        = 1..2;
  TNumParams           = 1..4;

  TParams              = array [TNumParams] of Integer;
  TPasswords           = array [TNumPasswords] of Integer;

  TvgHasp = class (TComponent)
  private
    FCheckErrorCode, FCheckLastStatus: Boolean;
    FConfigFileName: String;
    FIdleTime: Integer;
    FLastNetStatus, FLastSysStatus: Integer;
    FLogged: Boolean;
    FMode: THaspMode;
    FParams: TParams;
    FPasswords: TPasswords;
    FPort: THaspPort;
    FProgramID: Integer;
    FSeedCode: Integer;
    FServerName: String;
    FStorePasswords: Boolean;
    FStoreProgramID: Boolean;
    procedure CheckMode(Modes: THaspModes);
    function GetByte(Index: Integer): Byte;
    function GetDate: TDateTime;
    function GetTime: TDateTime;
    function GetIsHasp: Boolean;
    function GetHaspID: Integer;
    function GetMemorySizeActual: THaspMemorySize;
    function GetModeActual: THaspMode;
    function GetPassword(Index: Integer): Integer;
    function GetPortActual: Integer;
    function GetWord(Index: Integer): Word;
    procedure ReadOnlyProperty;
    procedure SetByte(Index: Integer; Value: Byte);
    procedure SetDate(Value: TDateTime);
    procedure SetSeedCode(Value: Integer);
    procedure SetTime(Value: TDateTime);
    procedure SetLogged(Value: Boolean);
    procedure SetMode(Value: THaspMode);
    procedure SetNothing(Value: Integer);
    procedure SetPassword(Index: Integer; Value: Integer);
    procedure SetProgramID(Value: Integer);
    procedure SetWord(Index: Integer; Value: Word);
  public
    { Methods }
    constructor Create(AOwner: TComponent); override;
    procedure CheckError(RaiseExcept: Boolean; Error: Integer);
    procedure ExecService(Service: Integer);
    procedure HaspCode(Code: Integer; var Params: TParams);
    procedure HaspStatus(var MemorySize: THaspMemorySize; var HaspMode: THaspMode; var HaspPort: Integer);
    procedure LastStatus(var NetStatus, SysStatus: Integer);
    procedure Login;
    procedure Logout;
    function LptNum: Integer;
    function ReadBlock(Addr: Integer; var Buff; Count: Integer): Integer;
    function ReadBlockTimeHasp(Addr: Integer; var Buff; Count: Integer): Integer;
    function ReadByte(Addr: Integer; var Value: Byte): Integer;
    function ReadDate(var Date: TDateTime): Integer;
    function ReadHaspID(var ID: Integer): Integer;
    function ReadTime(var Time: TDateTime): Integer;
    function ReadWord(Addr: Integer; var Value: Word): Integer;
    procedure SetConfigFileName(Value: String);
    procedure SetIdleTime(Value: Integer);
    procedure SetServerName(Value: String);
    function WriteByte(Addr: Integer; const Value: Byte): Integer;
    function WriteBlock(Addr: Integer; const Buff; Count: Integer): Integer;
    function WriteBlockTimeHasp(Addr: Integer; var Buff; Count: Integer): Integer;
    function WriteDate(const Date: TDateTime): Integer;
    function WriteTime(const Time: TDateTime): Integer;
    function WriteWord(Addr: Integer; const Value: Word): Integer;
    procedure UpdateLastStatus;
    { Properties }
    property Bytes[Index: Integer]: Byte read GetByte write SetByte;
    property Date: TDateTime read GetDate write SetDate;
    property HaspID: Integer read GetHaspID;
    property IsHasp: Boolean read GetIsHasp;
    property MemorySizeActual: THaspMemorySize read GetMemorySizeActual;
    property ModeActual: THaspMode read GetModeActual;
    property Params: TParams read FParams write FParams;
    property Passwords[Index: Integer]: Integer read GetPassword write SetPassword;
    property PortActual: Integer read GetPortActual;
    property Time: TDateTime read GetTime write SetTime;
    property Words[Index: Integer]: Word read GetWord write SetWord;
  published
    property CheckErrorCode: Boolean read FCheckErrorCode write FCheckErrorCode;
    property CheckLastStatus: Boolean read FCheckLastStatus write FCheckLastStatus;
    property ConfigFileName: String read FConfigFileName write FConfigFileName;
    property IdleTime: Integer read FIdleTime write FIdleTime default 2160;
    property LastNetStatus: Integer read FLastNetStatus write SetNothing stored False;
    property LastSysStatus: Integer read FLastSysStatus write SetNothing stored False;
    property Logged: Boolean read FLogged write SetLogged stored False;
    property Mode: THaspMode read FMode write SetMode default hmHasp;
    property Param1: Integer index 1 read FParams[1] write FParams[1] stored False;
    property Param2: Integer index 2 read FParams[2] write FParams[2] stored False;
    property Param3: Integer index 3 read FParams[3] write FParams[3] stored False;
    property Param4: Integer index 4 read FParams[4] write FParams[4] stored False;
    property Password1: Integer index 1 read FPasswords[1] write SetPassword stored FStorePasswords;
    property Password2: Integer index 2 read FPasswords[2] write SetPassword stored FStorePasswords;
    property Port: THaspPort read FPort write FPort default hpIBM25;
    property ProgramID: Integer read FProgramID write SetProgramID stored FStoreProgramID;
    property SeedCode: Integer read FSeedCode write SetSeedCode stored False;
    property ServerName: String read FServerName write FServerName;
    property StorePasswords: Boolean read FStorePasswords write FStorePasswords;
    property StoreProgramID: Boolean read FStoreProgramID write FStoreProgramID;
  end;

  EHaspError = class (Exception);

  EHaspDriverError = class (EHaspError)
  private
    FCode: Integer;
  public
    constructor Create(const Msg: String; const Code: Integer);
    property Code: Integer read FCode;
  end;

const
  LPT_IBM_ALL_HASP25           = 0;
  LPT_IBM_ALL_HASP36           = 50;
  LPT_NEC_ALL_HASP36           = 60;

  IS_HASP                      =  1;
  GET_HASP_CODE                =  2;
  READ_WORD                    =  3;
  WRITE_WORD                   =  4;
  GET_HASP_STATUS              =  5;
  GET_HASP_ID                  =  6;

  NET_LAST_STATUS              = 40;
  NET_GET_HASP_CODE            = 41;
  NET_LOGIN                    = 42;
  NET_LOGOUT                   = 43;
  NET_READ_WORD                = 44;
  NET_WRITE_WORD               = 45;
  NET_GET_HASP_ID              = 46;
  NET_SET_IDLE_TIME            = 48;

  READ_MEMO_BLOCK              = 50;
  WRITE_MEMO_BLOCK             = 51;

  NET_READ_MEMO_BLOCK          = 52;
  NET_WRITE_MEMO_BLOCK         = 53;

  TIME_SET_TIME                = 70;
  TIME_GET_TIME                = 71;
  TIME_SET_DATE                = 72;
  TIME_GET_DATE                = 73;
  TIME_WRITE_BYTE              = 74;
  TIME_READ_BYTE               = 75;
  TIME_WRITE_MEMO_BLOCK        = 76;
  TIME_READ_MEMO_BLOCK         = 77;
  TIME_GET_HASP_ID             = 78;

  NET_SET_CONFIG_FILENAME      = 85;
  NET_SET_SERVER_BY_NAME       = 96;

procedure Hasp(Service, SeedCode, LptNum,
  Pass1, Pass2: Integer; var p1, p2, p3, p4: Integer); external;

procedure HaspEx(Service, SeedCode, LptNum: Integer;
  Pass: TPasswords; var Params: TParams);

procedure HaspCheckError(ErrorCode: Integer);

implementation

end.

